@@ -2,8 +2,8 @@
 #define HELP_H
 
 enum {
-	HELP_TAG_FORMAT,
-	HELP_RENAME_FORMAT
+	HELP_TAG_FORMAT = 0,
+	HELP_RENAME_FORMAT = 1
 };
 
 
