@@ -136,6 +136,10 @@ int main(int argc, char *argv[])
 		g_warning("Failed to read preferences file");
 	atexit(write_preferences);
 
+	/* Set default icon & application name */
+	g_set_application_name("Audio Tag Tool");
+	gtk_window_set_default_icon_name("TagTool");
+
 	/* let other modules get what they need from the GladeXML object */
 	mw_init(xml);
 	fl_init(xml);
