@@ -63,11 +63,13 @@ void cb_settings_id3prefs(GtkWidget *widget, GdkEvent *event)
 
 void cb_help_contents(GtkWidget *widget, GdkEvent *event)
 {
+/*
 	GError *err = NULL;        
 
 	// XXX - should check with g_find_program_in_path()
 
 	g_spawn_command_line_async ("yelp "HELPDIR"tagtool.xml", &err);
+*/
 }
 
 void cb_help_about(GtkWidget *widget, GdkEvent *event)
@@ -142,8 +144,6 @@ void mw_init(GladeXML *xml)
 	/*
 	 * initialize the main window
 	 */
-	gtk_window_set_default_icon(gdk_pixbuf_new_from_file(DATADIR"/TagTool.png", NULL));
-
 	if (*width && *height)
 		gtk_window_set_default_size(w_main, *width, *height);
 	gtk_widget_show(GTK_WIDGET(w_main));
