@@ -1,7 +1,10 @@
+#include <config.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 #include <errno.h>
+#include <glib.h>
+#include <glib/gi18n.h>
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 #include <glade/glade.h>
@@ -112,7 +115,7 @@ static void tree_view_setup()
 
 	/* columns and renderers */
 	col = gtk_tree_view_column_new();
-	gtk_tree_view_column_set_title(col, "Field");
+	gtk_tree_view_column_set_title(col, _("Field"));
 	gtk_tree_view_append_column(tv_id3v2_frames, col);
 
 	renderer = gtk_cell_renderer_text_new();
@@ -121,7 +124,7 @@ static void tree_view_setup()
 	gtk_tree_view_column_add_attribute(col, renderer, "text", 0);
 
 	col = gtk_tree_view_column_new();
-	gtk_tree_view_column_set_title(col, "Text");
+	gtk_tree_view_column_set_title(col, _("Text"));
 	gtk_tree_view_append_column(tv_id3v2_frames, col);
 
 	renderer = gtk_cell_renderer_text_new();
@@ -269,11 +272,11 @@ static void update_form_v2()
 
 			if (extra_fields > 0) {
 				char str[16];
-				snprintf(str, sizeof(str), "Advanced (%i)", extra_fields);
+				snprintf(str, sizeof(str), _("Advanced (%i)"), extra_fields);
 				gtk_label_set_text(lab_id3v2_advanced, str);
 			}
 			else {
-				gtk_label_set_text(lab_id3v2_advanced, "Advanced");
+				gtk_label_set_text(lab_id3v2_advanced, _("Advanced"));
 			}
 		}
 		else {
@@ -411,10 +414,11 @@ static void write_to_file()
 
 	res = mpeg_file_write_changes(file);
 	if (res != AF_OK) {
-		char msg[128];
-		snprintf(msg, 128, "Error saving file \"%s\":\n%s (%d)", 
+		char msg[512];
+		snprintf(msg, sizeof(msg), 
+			 _("Error saving file \"%s\":\n%s (%d)"), 
 			 file->name, strerror(errno), errno);
-		message_box(w_main, "Error Saving File", msg, 0, GTK_STOCK_OK, NULL);
+		message_box(w_main, _("Error Saving File"), msg, 0, GTK_STOCK_OK, NULL);
 	}
 	else {
 		set_changed_flag(FALSE);
@@ -666,9 +670,9 @@ void mpeg_edit_unload()
 	if (changed_flag) {
 		int button;
 
-		button = message_box(w_main, "Save Changes", 
-				     "ID3 Tag has been modified. Save changes?", 1, 
-				     "Discard", GTK_STOCK_SAVE, NULL);
+		button = message_box(w_main, _("Save Changes"), 
+				     _("ID3 Tag has been modified. Save changes?"), 1, 
+				     _("Discard"), GTK_STOCK_SAVE, NULL);
 		if (button == 1) {
 			/* save button was pressed */
 			update_tag();
