@@ -285,7 +285,7 @@ static const char *get_text_field(ID3Frame* frame)
  * Sets the string stored in a frame's text or url field.  If the frame does 
  * not have a text or url field, has no effect.
  */
-static const void set_text_field(ID3Frame* frame, const char *text)
+static void set_text_field(ID3Frame* frame, const char *text)
 {
 	ID3Field *field;
 	char *convbuf;
