@@ -274,26 +274,32 @@ static void write_single_value(xmlNodePtr node, int type, void *data)
 {
 	char buf[32];
 	char *str;
+	gboolean free_str;
 
 	switch (PREF_TYPE_MASK & type) {
 		case PREF_INT:
 			snprintf(buf, 32, "%li", *(long *)data);
 			str = buf;
+			free_str = FALSE;
 			break;
 		case PREF_UINT:
 			snprintf(buf, 32, "%lu", *(unsigned long *)data);
 			str = buf;
+			free_str = FALSE;
 			break;
 		case PREF_REAL:
 			snprintf(buf, 32, "%.10g", *(double *)data);
 			str = buf;
+			free_str = FALSE;
 			break;
 		case PREF_STRING:
-			str = data;
+			str = xmlEncodeEntitiesReentrant(node->doc, data);
+			free_str = TRUE;
 			break;
 		case PREF_BOOLEAN:
 			strcpy(buf, (*(int*)data ? "true" : "false"));
 			str = buf;
+			free_str = FALSE;
 			break;
 		default: 
 
@@ -301,6 +307,9 @@ static void write_single_value(xmlNodePtr node, int type, void *data)
 	}
 
 	xmlNewChild(node, NULL, "value", str);
+
+	if (free_str)
+		free(str);
 }
 
 /*
