@@ -75,6 +75,8 @@ static gboolean append_field(GString *gstr, audio_file *af, int field)
 		free(temp);
 	}
 
+	str_trim(value);
+
 	/* convert to filesystem encoding */
 	temp = value;
 	value = str_filename_from_utf8(value, "utf8_conversion_error");
@@ -233,8 +235,7 @@ static void rename_files(GEList *file_list)
 
 		/* build the new file name (with path) */
 		g_string_truncate(new_full_name, 0);
-		p = strrchr(orig_full_name, '/');
-		if (p) 
+		if (format[0] != '/' && (p = strrchr(orig_full_name, '/'))) 
 			g_string_sprintfa(new_full_name, "%.*s/", (gint)(p-orig_full_name), orig_full_name);
 
 		if (!build_file_name(format, af, new_full_name)) {
