@@ -159,10 +159,10 @@ static parse_info *build_parse_info(const gchar *format)
 				i += 9;
 				j += 4;
 			} else if (strncmp(&aux_str[i], "<track>", 7) == 0) {
-				strncpy(&expr_str[j], "(.*)", 4);
+				strncpy(&expr_str[j], "([^ ]*)", 7);
 				info->track = pos++;
 				i += 7;
-				j += 4;
+				j += 7;
 			} else if (strncmp(&aux_str[i], "<genre>", 7) == 0) {
 				strncpy(&expr_str[j], "(.*)", 4);
 				info->genre = pos++;
